-----------------------------------------------------------------------------------------------
-- Client Lua Script for LiveStats
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "Apollo"
 
-----------------------------------------------------------------------------------------------
-- LiveStats Module Definition
-----------------------------------------------------------------------------------------------
local LiveStats = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
local kcrSelectedText = ApolloColor.new("UI_BtnTextHoloPressedFlyby")
local kcrNormalText = ApolloColor.new("UI_BtnTextHoloNormal")
local LoadSaves = false
local WndOpenedOnSave = false
local StatSize = 2
local IsLocked = false
local Opacity = 1
local Stats = {}
local StatNames = {}
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function LiveStats:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function LiveStats:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- LiveStats OnLoad
-----------------------------------------------------------------------------------------------
function LiveStats:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("LiveStats.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

function LiveStats:OnSave(eType)
	if eType == GameLib.CodeEnumAddonSaveLevel.Character then
		Stats.MaxHealth = self.wndMain:FindChild("MaxHealth"):IsChecked()
		Stats.MaxShield = self.wndMain:FindChild("MaxShield"):IsChecked()
		Stats.AssaultPower = self.wndMain:FindChild("AssaultPower"):IsChecked()
		Stats.SupportPower = self.wndMain:FindChild("SupportPower"):IsChecked()
		Stats.Vigor = self.wndMain:FindChild("Vigor"):IsChecked()
		Stats.StrikethroughChance = self.wndMain:FindChild("StrikethroughChance"):IsChecked()
		Stats.CriticalHitChance = self.wndMain:FindChild("CriticalHitChance"):IsChecked()
		Stats.CriticalHitSeverity = self.wndMain:FindChild("CriticalHitSeverity"):IsChecked()
		Stats.ArmorPierce = self.wndMain:FindChild("ArmorPierce"):IsChecked()
		Stats.MultiHitChance = self.wndMain:FindChild("MultiHitChance"):IsChecked()
		Stats.Lifesteal = self.wndMain:FindChild("Lifesteal"):IsChecked()
		Stats.CooldownReduction = self.wndMain:FindChild("CooldownReduction"):IsChecked()
		Stats.ShieldRegenRate = self.wndMain:FindChild("ShieldRegenRate"):IsChecked()
		Stats.ShieldRebootTime = self.wndMain:FindChild("ShieldRebootTime"):IsChecked()
		Stats.PhysicalResistance = self.wndMain:FindChild("PhysicalResistance"):IsChecked()
		Stats.TechnologyResistance = self.wndMain:FindChild("TechnologyResistance"):IsChecked()
		Stats.MagicResistance = self.wndMain:FindChild("MagicResistance"):IsChecked()
		Stats.DeflectChance = self.wndMain:FindChild("DeflectChance"):IsChecked()
		Stats.DeflectCriticalHitChance = self.wndMain:FindChild("DeflectCriticalHitChance"):IsChecked()
		Stats.CCResilience = self.wndMain:FindChild("CCResilience"):IsChecked()
		Stats.FocusRecoveryRate = self.wndMain:FindChild("FocusRecoveryRate"):IsChecked()
		Stats.FocusCostReduction = self.wndMain:FindChild("FocusCostReduction"):IsChecked()
		Stats.PVPPower = self.wndMain:FindChild("PVPPower"):IsChecked()
		Stats.PVPHealing = self.wndMain:FindChild("PVPHealing"):IsChecked()
		Stats.PVPDefense = self.wndMain:FindChild("PVPDefense"):IsChecked()
		Stats.MultiHitSeverity = self.wndMain:FindChild("MultiHitSeverity"):IsChecked()
		Stats.GlanceMitigation = self.wndMain:FindChild("GlanceMitigation"):IsChecked()
		Stats.GlanceChance = self.wndMain:FindChild("GlanceChance"):IsChecked()
		Stats.CriticalMitigation = self.wndMain:FindChild("CriticalMitigation"):IsChecked()
		Stats.ShieldMitigation = self.wndMain:FindChild("ShieldMitigation"):IsChecked()
		Stats.ShieldTickTime = self.wndMain:FindChild("ShieldTickTime"):IsChecked()
		Stats.FocusPool = self.wndMain:FindChild("FocusPool"):IsChecked()
		Stats.ReflectChance = self.wndMain:FindChild("ReflectChance"):IsChecked()
		Stats.ReflectDamage = self.wndMain:FindChild("ReflectDamage"):IsChecked()
		Stats.Intensity = self.wndMain:FindChild("Intensity"):IsChecked()
		
		Stats.MaxHealthEBox = self.wndMain:FindChild("MaxHealthEBox"):GetText()
		Stats.MaxShieldEBox = self.wndMain:FindChild("MaxShieldEBox"):GetText()
		Stats.AssaultPowerEBox = self.wndMain:FindChild("AssaultPowerEBox"):GetText()
		Stats.SupportPowerEBox = self.wndMain:FindChild("SupportPowerEBox"):GetText()
		Stats.VigorEBox = self.wndMain:FindChild("VigorEBox"):GetText()
		Stats.StrikethroughChanceEBox = self.wndMain:FindChild("StrikethroughChanceEBox"):GetText()
		Stats.CriticalHitChanceEBox = self.wndMain:FindChild("CriticalHitChanceEBox"):GetText()
		Stats.CriticalHitSeverityEBox = self.wndMain:FindChild("CriticalHitSeverityEBox"):GetText()
		Stats.ArmorPierceEBox = self.wndMain:FindChild("ArmorPierceEBox"):GetText()
		Stats.MultiHitChanceEBox = self.wndMain:FindChild("MultiHitChanceEBox"):GetText()
		Stats.LifestealEBox = self.wndMain:FindChild("LifestealEBox"):GetText()
		Stats.CooldownReductionEBox = self.wndMain:FindChild("CooldownReductionEBox"):GetText()
		Stats.ShieldRegenRateEBox = self.wndMain:FindChild("ShieldRegenRateEBox"):GetText()
		Stats.ShieldRebootTimeEBox = self.wndMain:FindChild("ShieldRebootTimeEBox"):GetText()
		Stats.PhysicalResistanceEBox = self.wndMain:FindChild("PhysicalResistanceEBox"):GetText()
		Stats.TechnologyResistanceEBox = self.wndMain:FindChild("TechnologyResistanceEBox"):GetText()
		Stats.MagicResistanceEBox = self.wndMain:FindChild("MagicResistanceEBox"):GetText()
		Stats.DeflectChanceEBox = self.wndMain:FindChild("DeflectChanceEBox"):GetText()
		Stats.DeflectCriticalHitChanceEBox = self.wndMain:FindChild("DeflectCriticalHitChanceEBox"):GetText()
		Stats.CCResilienceEBox = self.wndMain:FindChild("CCResilienceEBox"):GetText()
		Stats.FocusRecoveryRateEBox = self.wndMain:FindChild("FocusRecoveryRateEBox"):GetText()
		Stats.FocusCostReductionEBox = self.wndMain:FindChild("FocusCostReductionEBox"):GetText()
		Stats.PVPPowerEBox = self.wndMain:FindChild("PVPPowerEBox"):GetText()
		Stats.PVPHealingEBox = self.wndMain:FindChild("PVPHealingEBox"):GetText()
		Stats.PVPDefenseEBox = self.wndMain:FindChild("PVPDefenseEBox"):GetText()
		Stats.CriticalMitigationEBox = self.wndMain:FindChild("CriticalMitigationEBox"):GetText()
		Stats.ShieldMitigationEBox = self.wndMain:FindChild("ShieldMitigationEBox"):GetText()
		Stats.ShieldTickTimeEBox = self.wndMain:FindChild("ShieldTickTimeEBox"):GetText()
		Stats.FocusPoolEBox = self.wndMain:FindChild("FocusPoolEBox"):GetText()
		Stats.ReflectChanceEBox = self.wndMain:FindChild("ReflectChanceEBox"):GetText()
		Stats.ReflectDamageEBox = self.wndMain:FindChild("ReflectDamageEBox"):GetText()
		Stats.IntensityEBox = self.wndMain:FindChild("IntensityEBox"):GetText()
		Stats.GlanceChanceEBox = self.wndMain:FindChild("GlanceChanceEBox"):GetText()
		Stats.GlanceMitigationEBox = self.wndMain:FindChild("GlanceMitigationEBox"):GetText()
		Stats.MultiHitSeverityEBox = self.wndMain:FindChild("MultiHitSeverityEBox"):GetText()
			
		local tSavedData =
		{
			nStats = Stats,
			nStatSize = self.StatSize,
			nOpacity = self.Opacity,
			nWndOpenedOnSave = self.wndMain:IsShown(),
			nWndLocked = self.IsLocked, 
		}
		return tSavedData

		
		--return {nStats = Stats, nStatSize = self.StatSize, nOpacity = self.Opacity, nWndOpenedOnSave = self.wndMain:IsShown(),}
	end

	return nil
end

function LiveStats:OnRestore(eType, tSavedData)
	if eType == GameLib.CodeEnumAddonSaveLevel.Character then
		self.tSavedData = tSavedData
		if tSavedData.nStats then
			Stats = tSavedData.nStats
			self.LoadSaves = true
		end
		StatNames = tSavedData.nStatNames
		self.StatSize = tSavedData.nStatSize 
		self.Opacity = tSavedData.nOpacity
		self.IsLocked = tSavedData.nWndLocked
		self.WndOpenedOnSave = tSavedData.nWndOpenedOnSave
		if not tSavedData or tSavedData.nSaveVersion ~= knSaveVersion then
			return
		end
	end
end

function LiveStats:LoadStatsFromSave()
	for IKey,IValue in pairs(Stats) do
		if string.find(IKey, "EBox") then
			-- Do Nothing
		else
			if self.wndMain:FindChild(IKey) ~= nil then
				self.wndMain:FindChild(IKey):SetCheck(IValue)
			end
		end
		
	end

	for IKey,IValue in pairs(Stats) do
		if string.find(IKey, "EBox") then
			if self.wndMain:FindChild(IKey) ~= nil then
				self.wndMain:FindChild(IKey):SetText(IValue)
				local wnd = string.sub(IKey, 0, -5)
				self:UpdateEBox(self.wndMain:FindChild(wnd), nil, nil)
			end
		else
			-- Do Nothing
		end
		
	end

	if self.StatSize == nil then self.StatSize = 2 end
	self.wndMain:FindChild("ScalingStatsSliderBar"):SetValue(self.StatSize)
	self.wndMain:FindChild("ScalingStatsEditBox"):SetText(self.StatSize)
	if self.Opacity == nil then self.Opacity = 1 end
	self.wndMain:FindChild("LiveStatsContainer"):SetOpacity(self.Opacity, 1)
	self.wndMain:FindChild("OpacityStatsSliderBar"):SetValue(self.Opacity)
	self.wndMain:FindChild("OpacityStatsEditBox"):SetText(string.format("%.2f",self.Opacity))
	self.LoadSaves = false
end

-----------------------------------------------------------------------------------------------
-- LiveStats OnDocLoaded
-----------------------------------------------------------------------------------------------
function LiveStats:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "LiveStatsForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		self.wndMain:Show(false, true)
		
		self.wndlocal = self.wndMain

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("livestats", "OnLiveStatsOn", self)
		Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
		Apollo.RegisterEventHandler("ToggleLiveStats", "OnLiveStatsOn", self)
		Apollo.RegisterEventHandler("WindowManagementReady", 	"OnWindowManagementReady", self)

		-- Do additional Addon initialization here
		if (self.LoadSaves) then
			self:LoadStatsFromSave()
			if(self.WndOpenedOnSave) then
				self:OnLiveStatsOn()
			end
		end
	end
	
end

-----------------------------------------------------------------------------------------------
-- LiveStats Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here
function LiveStats:OnInterfaceMenuListHasLoaded()
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "Live Stats", {"ToggleLiveStats", "", "CRB_Basekit:kitIcon_Holo_HazardObserver"})
end

-- on SlashCommand "/livestats"
function LiveStats:OnLiveStatsOn()
	if (self.wndMain:IsVisible()) then
		self.wndMain:Close()
		self.timer:Stop()
	else
		if (self.LoadSaves) then
			self:LoadStatsFromSave()
		end
		self.wndMain:Invoke()
		self.timer = ApolloTimer.Create(1.0, true, "OnTimer", self)
	end
end

-- on timer
function LiveStats:OnTimer()
	self:DrawAttributes()
end

function LiveStats:OnWindowManagementReady()
	Event_FireGenericEvent("WindowManagementRegister", {strName = "LiveStats", nSaveVersion = 2})
	Event_FireGenericEvent("WindowManagementAdd", {wnd = self.wndMain, strName = "LiveStats"})
end

-----------------------------------------------------------------------------------------------
-- LiveStatsForm Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function LiveStats:OnOK()
	self.wndMain:Close() -- hide the window
end

-- when the Cancel button is clicked
function LiveStats:OnCancel()
	--self.timer = nil
	self:OnLiveStatsOn() -- hide the window
end

function LiveStats:OnOptionsMenuToggle()
	self.wndMain:FindChild("OptionsContainer"):Show(self.wndMain:FindChild("OptionsBtn"):IsChecked())
end

function LiveStats:OnOptionsCloseClick()
	self.wndMain:FindChild("OptionsBtn"):SetCheck(false)
	self:OnOptionsMenuToggle()
end

function LiveStats:OnOptionsReset()
	self.wndMain:FindChild("MaxHealth"):SetCheck(false)
	self.wndMain:FindChild("MaxShield"):SetCheck(false)
	self.wndMain:FindChild("AssaultPower"):SetCheck(false)
	self.wndMain:FindChild("SupportPower"):SetCheck(false)
	self.wndMain:FindChild("Vigor"):SetCheck(false)
	self.wndMain:FindChild("StrikethroughChance"):SetCheck(false)
	self.wndMain:FindChild("CriticalHitChance"):SetCheck(false)
	self.wndMain:FindChild("CriticalHitSeverity"):SetCheck(false)
	self.wndMain:FindChild("ArmorPierce"):SetCheck(false)
	self.wndMain:FindChild("MultiHitChance"):SetCheck(false)
	self.wndMain:FindChild("Lifesteal"):SetCheck(false)
	self.wndMain:FindChild("CooldownReduction"):SetCheck(false)
	self.wndMain:FindChild("ShieldRegenRate"):SetCheck(false)
	self.wndMain:FindChild("ShieldRebootTime"):SetCheck(false)
	self.wndMain:FindChild("PhysicalResistance"):SetCheck(false)
	self.wndMain:FindChild("TechnologyResistance"):SetCheck(false)
	self.wndMain:FindChild("MagicResistance"):SetCheck(false)
	self.wndMain:FindChild("DeflectChance"):SetCheck(false)
	self.wndMain:FindChild("DeflectCriticalHitChance"):SetCheck(false)
	self.wndMain:FindChild("CCResilience"):SetCheck(false)
	self.wndMain:FindChild("FocusRecoveryRate"):SetCheck(false)
	self.wndMain:FindChild("FocusCostReduction"):SetCheck(false)
	self.wndMain:FindChild("PVPPower"):SetCheck(false)
	self.wndMain:FindChild("PVPHealing"):SetCheck(false)
	self.wndMain:FindChild("PVPDefense"):SetCheck(false)
	self.wndMain:FindChild("MultiHitSeverity"):SetCheck(false)
	self.wndMain:FindChild("GlanceMitigation"):SetCheck(false)
	self.wndMain:FindChild("GlanceChance"):SetCheck(false)
	self.wndMain:FindChild("CriticalMitigation"):SetCheck(false)
	self.wndMain:FindChild("ShieldMitigation"):SetCheck(false)
	self.wndMain:FindChild("ShieldTickTime"):SetCheck(false)
	self.wndMain:FindChild("FocusPool"):SetCheck(false)
	self.wndMain:FindChild("ReflectChance"):SetCheck(false)
	self.wndMain:FindChild("ReflectDamage"):SetCheck(false)
	self.wndMain:FindChild("Intensity"):SetCheck(false)
	
	self.wndMain:FindChild("MaxHealthEBox"):SetText("Max Health")
	self.wndMain:FindChild("MaxHealthEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("MaxShieldEBox"):SetText("Max Shield")
	self.wndMain:FindChild("MaxShieldEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("AssaultPowerEBox"):SetText("Assault Power")
	self.wndMain:FindChild("AssaultPowerEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("SupportPowerEBox"):SetText("Support Power")
	self.wndMain:FindChild("SupportPowerEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("VigorEBox"):SetText("Vigor")
	self.wndMain:FindChild("VigorEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("StrikethroughChanceEBox"):SetText("Strikethrough")
	self.wndMain:FindChild("StrikethroughChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("CriticalHitChanceEBox"):SetText("Critical Hit Chance")
	self.wndMain:FindChild("CriticalHitChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("CriticalHitSeverityEBox"):SetText("Critical Hit Severity")
	self.wndMain:FindChild("CriticalHitSeverityEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ArmorPierceEBox"):SetText("Armor Pierce")
	self.wndMain:FindChild("ArmorPierceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("MultiHitChanceEBox"):SetText("Multi-Hit Chance")
	self.wndMain:FindChild("MultiHitChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("LifestealEBox"):SetText("Lifesteal")
	self.wndMain:FindChild("LifestealEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("CooldownReductionEBox"):SetText("Cooldown Reduction")
	self.wndMain:FindChild("CooldownReductionEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ShieldRegenRateEBox"):SetText("Shield Regen Rate")
	self.wndMain:FindChild("ShieldRegenRateEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ShieldRebootTimeEBox"):SetText("Shield Reboot Time")
	self.wndMain:FindChild("ShieldRebootTimeEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("PhysicalResistanceEBox"):SetText("Physical Mitigation")
	self.wndMain:FindChild("PhysicalResistanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("TechnologyResistanceEBox"):SetText("Technology Mitigation")
	self.wndMain:FindChild("TechnologyResistanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("MagicResistanceEBox"):SetText("Magic Mitigation")
	self.wndMain:FindChild("MagicResistanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("DeflectChanceEBox"):SetText("Deflect Chance")
	self.wndMain:FindChild("DeflectChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("DeflectCriticalHitChanceEBox"):SetText("Deflect Critical Hit Chance")
	self.wndMain:FindChild("DeflectCriticalHitChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("CCResilienceEBox"):SetText("CC Duration")
	self.wndMain:FindChild("CCResilienceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("FocusRecoveryRateEBox"):SetText("Focus Recovery Rate")
	self.wndMain:FindChild("FocusRecoveryRateEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("FocusCostReductionEBox"):SetText("Focus Cost Reduction")
	self.wndMain:FindChild("FocusCostReductionEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("PVPPowerEBox"):SetText("PVP Power")
	self.wndMain:FindChild("PVPPowerEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("PVPHealingEBox"):SetText("PVP Healing")
	self.wndMain:FindChild("PVPHealingEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("PVPDefenseEBox"):SetText("PVP Defense")
	self.wndMain:FindChild("PVPDefenseEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("MultiHitSeverityEBox"):SetText("Multi-Hit Severity")
	self.wndMain:FindChild("MultiHitSeverityEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("GlanceMitigationEBox"):SetText("Glance Mitigation")
	self.wndMain:FindChild("GlanceMitigationEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("GlanceChanceEBox"):SetText("Glance Chance")
	self.wndMain:FindChild("GlanceChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("CriticalMitigationEBox"):SetText("Critical Mitigation")
	self.wndMain:FindChild("CriticalMitigationEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ShieldMitigationEBox"):SetText("Shield Mitigation")
	self.wndMain:FindChild("ShieldMitigationEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ShieldTickTimeEBox"):SetText("Shield Tick Time")
	self.wndMain:FindChild("ShieldTickTimeEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("FocusPoolEBox"):SetText("Focus Pool")
	self.wndMain:FindChild("FocusPoolEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ReflectChanceEBox"):SetText("Reflect Chance")
	self.wndMain:FindChild("ReflectChanceEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("ReflectDamageEBox"):SetText("Reflect Damage")
	self.wndMain:FindChild("ReflectDamageEBox"):SetTextColor("UI_BtnTextHoloNormal")
	self.wndMain:FindChild("IntensityEBox"):SetText("Intensity")
	self.wndMain:FindChild("IntensityEBox"):SetTextColor("UI_BtnTextHoloNormal")
end

function LiveStats:OnOptionsApply()
	self:OnOptionsCloseClick()
	self:DrawAttributes()
end

function LiveStats:OnOptionsSliderChanged()
	self.StatSize = math.floor(self.wndMain:FindChild("ScalingStatsSliderBar"):GetValue())
	self.wndMain:FindChild("ScalingStatsEditBox"):SetText(self.StatSize)
end

function LiveStats:OnOpacityChange( wndHandler, wndControl, fNewValue, fOldValue )
	self.Opacity = self.wndMain:FindChild("OpacityStatsSliderBar"):GetValue()
	self.wndMain:FindChild("OpacityStatsEditBox"):SetText(string.format("%.2f",self.Opacity))
end

function LiveStats:UpdateEBox( wndHandler, wndControl, eMouseButton )
	local nstat = wndHandler:GetName()
	if wndHandler:IsChecked() then
		self.wndMain:FindChild(nstat.."EBox"):SetTextColor("White")
	else
		self.wndMain:FindChild(nstat.."EBox"):SetTextColor("UI_BtnTextHoloNormal")
	end
	
end

function LiveStats:OnLockBtnToggle( wndHandler, wndControl, strType, iData, bDragDropHasBeenReset )
	local check = wndHandler:IsChecked()
	self.wndMain:FindChild("LiveStatsForm"):SetStyle("Moveable", not check)
	self.wndMain:FindChild("BtnWnd"):SetStyle("AutoFade", check)
end

-----------------------------------------------------------------------------------------------
-- LiveStats Instance
-----------------------------------------------------------------------------------------------
local LiveStatsInst = LiveStats:new()
LiveStatsInst:Init()

-----------------------------------------------------------------------------------------------
-- Get Attributes
-----------------------------------------------------------------------------------------------
function LiveStats:DrawAttributes()
	local unitPlayer = GameLib.GetPlayerUnit()
	if unitPlayer == nil then
		return
	end
	
	self.wndMain:FindChild("AttFrame"):DestroyChildren()

	local arProperties = unitPlayer:GetUnitProperties()
	
	local arSecondaryAttributes = {}
	local stats = {}
	
	if self.wndMain:FindChild("MaxHealth"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("MaxHealthEBox"):GetText(), --Apollo.GetString("Character_MaxHealthLabel"),
				strValue 		= math.ceil(unitPlayer:GetMaxHealth()),
				strTooltip 	= Apollo.GetString("CRB_Health_Description")
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("MaxShield"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("MaxShieldEBox"):GetText(), --Apollo.GetString("Character_MaxShieldLabel"),
				strValue 		= math.ceil(unitPlayer:GetShieldCapacityMax()),
				strTooltip 	= Apollo.GetString("Character_MaxShieldTooltip")
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("AssaultPower"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("AssaultPowerEBox"):GetText(), --Apollo.GetString("AttributeAssaultPower"),
				strValue 		= math.floor(unitPlayer:GetAssaultPower()),
				strTooltip 	= Apollo.GetString("Character_AssaultTooltip")
			}
		table.insert(stats, stat)
	end
	
	
	if self.wndMain:FindChild("SupportPower"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("SupportPowerEBox"):GetText(), --Apollo.GetString("AttributeSupportPower"),
				strValue 		= math.floor(unitPlayer:GetSupportPower()),
				strTooltip 	= Apollo.GetString("Character_SupportTooltip")
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("Vigor"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("VigorEBox"):GetText(), 
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetVigor().nAmount, 2, true)), 
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_VigorTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingVigor).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetVigor().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseVigor).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseVigor).fValue * 100, 2, true)) 
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("StrikethroughChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("StrikethroughChanceEBox"):GetText(), --Apollo.GetString("Character_StrikethroughLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetStrikethroughChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_StrikethroughTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Rating_AvoidReduce).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetStrikethroughChance().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseAvoidReduceChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseAvoidReduceChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("CriticalHitChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("CriticalHitChanceEBox"):GetText(), --Apollo.GetString("Character_CritChanceLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetCritChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_CritTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Rating_CritChanceIncrease).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetCritChance().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseCritChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseCritChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("CriticalHitSeverity"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("CriticalHitSeverityEBox"):GetText(), --Apollo.GetString("Character_CritSeverityLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetCritSeverity().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_CritSevTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingCritSeverityIncrease).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetCritSeverity().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.CriticalHitSeverityMultiplier).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.CriticalHitSeverityMultiplier).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("ArmorPierce"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ArmorPierceEBox"):GetText(), --Apollo.GetString("Character_ArmorPenLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetArmorPierce().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_ArmorPenTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingArmorPierce).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetArmorPierce().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.IgnoreArmorBase).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.IgnoreArmorBase).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("MultiHitChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("MultiHitChanceEBox"):GetText(), --Apollo.GetString("Character_ShieldPenLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetMultiHitChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_MultiHitChanceTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingMultiHitChance).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetMultiHitChance().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseMultiHitChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseMultiHitChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("Lifesteal"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("LifestealEBox"):GetText(), --Apollo.GetString("Character_LifestealLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetLifesteal().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_LifestealTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingLifesteal).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetLifesteal().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseLifesteal).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseLifesteal).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end

	if self.wndMain:FindChild("CooldownReduction"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("CooldownReductionEBox"):GetText(), --Apollo.GetString("Character_HasteLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetCooldownReductionModifier(), 2, true)),
				strTooltip 	= Apollo.GetString("Character_HasteTooltip")
			}
		table.insert(stats, stat)
	end

	if self.wndMain:FindChild("ShieldRegenRate"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ShieldRegenRateEBox"):GetText(), --Apollo.GetString("Character_ShieldRegenPercentLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetShieldRegenPct(), 2, true)),
				strTooltip 	= Apollo.GetString("Character_ShieldRegenPercentTooltip")
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("ShieldRebootTime"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ShieldRebootTimeEBox"):GetText(), --Apollo.GetString("Character_ShieldRebootLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_SecondsLabel"), Apollo.FormatNumber(unitPlayer:GetShieldRebootTime(), 2, true)),
				strTooltip 	= Apollo.GetString("Character_ShieldRebootTooltip")
				
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("PhysicalResistance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("PhysicalResistanceEBox"):GetText(), --Apollo.GetString("Character_PhysicalMitLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetPhysicalMitigation().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_PhysMitTooltip"), Apollo.FormatNumber(unitPlayer:GetPhysicalMitigationRating() + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Armor).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetPhysicalMitigation().nAmount - ((unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffsetPhysical).fValue + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffset).fValue) * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.ResistPhysical).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Armor).fValue, 2, true), Apollo.FormatNumber((unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffsetPhysical).fValue + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffset).fValue) * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("TechnologyResistance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("TechnologyResistanceEBox"):GetText(), --Apollo.GetString("Character_TechMitLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetTechMitigation().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_TechMitTooltip"), Apollo.FormatNumber(unitPlayer:GetTechMitigationRating() + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Armor).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetTechMitigation().nAmount - ((unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffsetTech).fValue + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffset).fValue) * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.ResistTech).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Armor).fValue, 2, true), Apollo.FormatNumber((unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffsetTech).fValue + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffset).fValue) * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("MagicResistance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("MagicResistanceEBox"):GetText(), --Apollo.GetString("Character_MagicMitLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetMagicMitigation().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_MagicMitTooltip"), Apollo.FormatNumber(unitPlayer:GetMagicMitigationRating() + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Armor).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetMagicMitigation().nAmount - ((unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffsetMagic).fValue + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffset).fValue) * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.ResistMagic).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Armor).fValue, 2, true), Apollo.FormatNumber((unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffsetMagic).fValue + unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.DamageMitigationPctOffset).fValue) * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("DeflectChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("DeflectChanceEBox"):GetText(), --Apollo.GetString("Character_DeflectLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetDeflectChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_DeflectTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Rating_AvoidIncrease).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetDeflectChance().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseAvoidChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseAvoidChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("DeflectCriticalHitChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("DeflectCriticalHitChanceEBox"):GetText(), --Apollo.GetString("Character_DeflectCritLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetDeflectCritChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_CritDeflectTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.Rating_CritChanceDecrease).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetDeflectCritChance().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseAvoidCritChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseAvoidCritChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end

	if self.wndMain:FindChild("CCResilience"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("CCResilienceEBox"):GetText(), --Apollo.GetString("Character_ResilianceLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetCCDurationModifier().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_CCDurationTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingCCResilience).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetCCDurationModifier().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.CCDurationModifier).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.CCDurationModifier).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("FocusRecoveryRate"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("FocusRecoveryRateEBox"):GetText(), --Apollo.GetString("Character_ManaRecoveryLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetFocusRegenInCombat().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_ManaRecoveryTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingFocusRecovery).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetFocusRegenInCombat().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseFocusRecoveryInCombat).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseFocusRecoveryInCombat).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end

	if self.wndMain:FindChild("FocusCostReduction"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("FocusCostReductionEBox"):GetText(), --Apollo.GetString("Character_ManaCostRedLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.FocusCostModifier).fValue * 100, 2, true)),
				strTooltip 	= Apollo.GetString("Character_ManaCostRedTooltip")
			}
		table.insert(stats, stat)
	end

	if self.wndMain:FindChild("PVPPower"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("PVPPowerEBox"):GetText(), --Apollo.GetString("Character_PvPOffenseLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetPvPDamageI(), 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_PvPOffenseTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPOffensiveRating).fValue, 2, true),
								  Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPOffensePctOffset).fValue * 100, 2, true), Apollo.FormatNumber(unitPlayer:GetPvPDamageO(), 2, true), Apollo.FormatNumber(unitPlayer:GetPvPDamageI() - unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPOffensePctOffset).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("PVPHealing"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("PVPHealingEBox"):GetText(), --Apollo.GetString("Character_PvPHealLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetPvPHealingI(), 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_PvPHealingTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPOffensiveRating).fValue, 2, true),
								  Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPOffensePctOffset).fValue * 100, 2, true), Apollo.FormatNumber(unitPlayer:GetPvPHealingO(), 2, true), Apollo.FormatNumber(unitPlayer:GetPvPHealingI() - unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPOffensePctOffset).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("PVPDefense"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("PVPDefenseEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetPvPDefenseI(), 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_PvPDefenseTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPDefensiveRating).fValue, 2, true),
								  Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPDefensePctOffset).fValue * 100, 2, true), Apollo.FormatNumber(unitPlayer:GetPvPDefenseO(), 2, true), Apollo.FormatNumber(unitPlayer:GetPvPDefenseI() - unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.PvPDefensePctOffset).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("MultiHitSeverity"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("MultiHitSeverityEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetMultiHitAmount().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_MultiHitSeverityTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingMultiHitAmount).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetMultiHitAmount().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseMultiHitAmount).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseMultiHitAmount).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("GlanceMitigation"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("GlanceMitigationEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetGlanceAmount().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_GlanceSeverityTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingGlanceAmount).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetGlanceAmount().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseGlanceAmount).fValue  * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseGlanceAmount).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("GlanceChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("GlanceChanceEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetGlanceChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_GlanceChanceTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingGlanceChance).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetGlanceChance().nAmount -(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseGlanceChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseGlanceChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("CriticalMitigation"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("CriticalMitigationEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetCriticalMitigation().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_CritMitigationTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingCriticalMitigation).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetCriticalMitigation().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseCriticalMitigation).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseCriticalMitigation).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("ShieldMitigation"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ShieldMitigationEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetShieldMitigationPct(), 2, true)),
				strTooltip 	= Apollo.GetString("Character_ShieldMitigation_Tooltip")
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("ShieldTickTime"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ShieldTickTimeEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_SecondsLabel"), Apollo.FormatNumber(unitPlayer:GetShieldTickTime(), 2, true)),
				strTooltip 	= Apollo.GetString("Character_ShieldTickTime_Tooltip")
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("FocusPool"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("FocusPoolEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= Apollo.FormatNumber(unitPlayer:GetMaxFocus(), 0, true),
				strTooltip 	= Apollo.GetString("Character_FocusPool")
				
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("ReflectChance"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ReflectChanceEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetDamageReflectChance().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_ReflectChanceTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingDamageReflectChance).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetDamageReflectChance().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseDamageReflectChance).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseDamageReflectChance).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("ReflectDamage"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("ReflectDamageEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetDamageReflectAmount().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_ReflectSeverityTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingDamageReflectAmount).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetDamageReflectAmount().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseDamageReflectAmount).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseDamageReflectAmount).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	if self.wndMain:FindChild("Intensity"):IsChecked() then
		local stat = 
			{
				strName 	= self.wndMain:FindChild("IntensityEBox"):GetText(), --Apollo.GetString("Character_PvPDefLabel"),
				strValue 	= String_GetWeaselString(Apollo.GetString("Character_PercentAppendLabel"), Apollo.FormatNumber(unitPlayer:GetIntensity().nAmount, 2, true)),
				strTooltip 	= String_GetWeaselString(Apollo.GetString("Character_IntensityTooltip"), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.RatingIntensity).fValue, 2, true), Apollo.FormatNumber(unitPlayer:GetIntensity().nAmount - (unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseIntensity).fValue * 100), 2, true), Apollo.FormatNumber(unitPlayer:GetUnitProperty(Unit.CodeEnumProperties.BaseIntensity).fValue * 100, 2, true))
			}
		table.insert(stats, stat)
	end
	
	table.insert(arSecondaryAttributes, stats)
	
	local wndParent = self.wndMain:FindChild("AttFrame")
	local StatsCount = 0
	
	for idx, tCur in pairs (arSecondaryAttributes) do
		local wndItemContainer = Apollo.LoadForm(self.xmlDoc, "AttCont", wndParent, self)
		local wndItemHolder = Apollo.LoadForm(self.xmlDoc, "AttContHolder", wndItemContainer , self)
		local nContainerLeft, nContainerTop, nContainerRight, nContainerBottom = wndItemHolder:GetAnchorOffsets()

		local strIcon = ""
		for idxInner, tCurInner in pairs (arSecondaryAttributes[idx]) do
			StatsCount = StatsCount + 1
			--str = string.gsub(str, "%s+", "") removes all spaces in string
			self:StatsDrawHelper(wndItemHolder , tCurInner.strName, tCurInner.strValue, strIcon, "ff39b5d4", tCurInner.strTooltip)
		end

		local nNewBottom = wndItemHolder:ArrangeChildrenVert()
		wndItemHolder:SetAnchorOffsets(nContainerLeft, nContainerTop, nContainerRight, nNewBottom )
		wndItemContainer:SetAnchorOffsets(nContainerLeft, nContainerTop, nContainerRight, nNewBottom + 11)
	end
	
	local wndLiveStatsForm = self.wndMain:FindChild("LiveStatsForm")
	local nLiveStatsFormLeft, nLiveStatsFormTop, nLiveStatsFormRight, nLiveStatsFormBottom = wndLiveStatsForm:GetAnchorOffsets()
	if self.StatSize == nil then self.StatSize = 2 end
	wndLiveStatsForm:SetAnchorOffsets(nLiveStatsFormLeft, nLiveStatsFormTop, nLiveStatsFormRight, (nLiveStatsFormTop + 35) + ((18 + self.StatSize) * StatsCount))
	if self.Opacity == nil then self.Opacity = 1 end
	self.wndMain:FindChild("LiveStatsContainer"):SetOpacity(self.Opacity, 1)
	wndParent:ArrangeChildrenVert()
	
end

function LiveStats:StatsDrawHelper(wndContainer, strName, strValue, strIcon, crTextColor, strTooltip)

	local wndItem = Apollo.LoadForm(self.xmlDoc, "AttItem", wndContainer, self)
	wndItem:FindChild("StatLabel"):SetAML(string.format("<T Font=\"CRB_InterfaceSmall\" TextColor=\"%s\">%s</T>", crTextColor, strName))
	wndItem:FindChild("StatValue"):SetText(strValue) --SetAML(string.format("<T Font=\"CRB_Header9\" TextColor=\"%s\">%s</T>", crTextColor, strValue))
	wndItem:SetTooltip(strTooltip)
end
